

class Api(object):
    """TBD
    """

    def set_config(self, content):
        """TBD
        """
        raise NotImplementedError

    def set_port_link(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_results(self, content):
        """TBD
        """
        raise NotImplementedError
